# DVote example

This plugin provides cryptographic and communication libraries to interact with decentralized votes running on the Vocdoni platform.

## Getting Started
Import the Dart library on your project and use the static functions available on the `Dvote` class

```dart
import 'package:dvote/dvote.dart';
```

## HD Wallet management
Generating mnemonics and computing private/public keys

```dart
final mnemonic = await generateMnemonic();
final privateKey = await mnemonicToPrivateKey(mnemonic, hdPath: "m/44'/60'/0'/0/5");
final publicKey = await mnemonicToPublicKey(mnemonic);
final address = await mnemonicToAddress(mnemonic);
```

## Signing
Computing signatures using ECDSA cryptography

```dart
final signature = await signString(messageToSign, privateKey);
final valid = await verifySignature(signature, messageToSign, publicKey);
```

## Encryption
Using symmetric AES-GCM encryption to store private data on a mobile device

```dart
final encrypted = await encryptString(myText, myPassphrase);
final decrypted = await decryptString(encrypted, myPassphrase);
```

## Entity API
Use a Vocdoni Gateway to fetch the metadata of an Entity

```dart
import 'package:dvote/dvote.dart';

final entityMeta = await fetchEntity(
    entityId, resolverAddress, vocGateway, web3Gateway,
    networkId: "1234", entryPoints: [],
);

```

## File API
Use a Vocdoni Gateway to fetch static content from the net

```dart
import 'package:dvote/dvote.dart';

final contentUri = ContentURI("ipfs://QmSsfizN4rpSDLRZw3X3WooCPpnBktZ5bEShvmLZuf88iw,https://my-server/file.txt");
final gatewayUri = "ws://hostname:2082/dvote";
final gwPublicKey = "02325f284f50fa52d53579c7873a480b351cc20f7780fa556929f5017283ad2449"

final content = await fetchFileString(contentUri, gatewayUri, gatewayPublicKey: gwPublicKey);
```
